==> gimp-3.0.6.tar.xz: gimp-3.0.6/app/core/gimpguideundo.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_GUIDE_UNDO_H__
#define __GIMP_GUIDE_UNDO_H__


#include "gimpauxitemundo.h"


#define GIMP_TYPE_GUIDE_UNDO            (gimp_guide_undo_get_type ())
#define GIMP_GUIDE_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndo))
#define GIMP_GUIDE_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndoClass))
#define GIMP_IS_GUIDE_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_GUIDE_UNDO))
#define GIMP_IS_GUIDE_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_GUIDE_UNDO))
#define GIMP_GUIDE_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndoClass))


typedef struct _GimpGuideUndo      GimpGuideUndo;
typedef struct _GimpGuideUndoClass GimpGuideUndoClass;

struct _GimpGuideUndo
{
  GimpAuxItemUndo      parent_instance;

  GimpOrientationType  orientation;
  gint                 position;
};

struct _GimpGuideUndoClass
{
  GimpAuxItemUndoClass  parent_class;
};


GType   gimp_guide_undo_get_type (void) G_GNUC_CONST;


#endif /* __GIMP_GUIDE_UNDO_H__ */

==> gimp-3.1.4.tar.xz: gimp-3.1.4/app/core/gimpguideundo.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#pragma once

#include "gimpauxitemundo.h"


#define GIMP_TYPE_GUIDE_UNDO            (gimp_guide_undo_get_type ())
#define GIMP_GUIDE_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndo))
#define GIMP_GUIDE_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndoClass))
#define GIMP_IS_GUIDE_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_GUIDE_UNDO))
#define GIMP_IS_GUIDE_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_GUIDE_UNDO))
#define GIMP_GUIDE_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_GUIDE_UNDO, GimpGuideUndoClass))


typedef struct _GimpGuideUndo      GimpGuideUndo;
typedef struct _GimpGuideUndoClass GimpGuideUndoClass;

struct _GimpGuideUndo
{
  GimpAuxItemUndo      parent_instance;

  GimpOrientationType  orientation;
  gint                 position;
};

struct _GimpGuideUndoClass
{
  GimpAuxItemUndoClass  parent_class;
};


GType   gimp_guide_undo_get_type (void) G_GNUC_CONST;
